fn candidate_primary_key_stream(
input: BoxedRecordBatchStream,
filter: Option<CachedPrimaryKeyFilter>,
) -> BoxedRecordBatchStreamExpand description
Filters a source by encoded-primary-key predicates and emits one binary row per local key.
fn candidate_primary_key_stream(
input: BoxedRecordBatchStream,
filter: Option<CachedPrimaryKeyFilter>,
) -> BoxedRecordBatchStreamFilters a source by encoded-primary-key predicates and emits one binary row per local key.